﻿using MotionAnalysis;
using NUnit.Framework;
using System.Collections.Generic;
using Windows.Kinect;

public class MotionDiscriminatorTests
{
    [Test]
    public void IsPreseted_False_When_Constructed()
    {
        var obj = new MotionDiscriminator();

        var expected = false;
        var actual = obj.IsPreseted;

        Assert.AreEqual(expected, actual, "IsPreseted should be false when constructed");
    }

    [Test]
    public void Motion_Unknown_When_Constructed()
    {
        var obj = new MotionDiscriminator();

        var expected = MotionState.UNKNOWN;
        var actual = obj.Motion;

        Assert.AreEqual(expected, actual, "Motion should be unknown when constructed");
    }

    [Test]
    public void IsPreset_False_When_Preset_Without_KneeJoints()
    {
        var obj = new MotionDiscriminator();
        obj.Preset(new BodyDummy());

        var expected = false;
        var actual = obj.IsPreseted;

        Assert.AreEqual(expected, actual, "IsPreseted should be false when preset without knee joints");
    }

    [Test]
    public void IsPreset_True_When_Preset_With_KneeJoints()
    {
        var obj = new MotionDiscriminator();
        obj.Preset(new KneeJointsBodyStub());

        var expected = true;
        var actual = obj.IsPreseted;

        Assert.AreEqual(expected, actual, "IsPreseted should be true when preset with knee joints");
    }

    [Test]
    public void Motion_Unknown_When_DistHandBaseSpineShoulder_Smaller_Than_0()
    {
        
    }
}

public class BodyDummy : BodyFake
{
    public BodyDummy()
    {
        Joints = new Dictionary<JointType, KinectModule.IJoint>();
    }
}

public class KneeJointsBodyStub : BodyFake
{
    public KneeJointsBodyStub()
    {
        Joints = new Dictionary<JointType, KinectModule.IJoint>
        {
            { JointType.KneeLeft,      new JointStub() },
            { JointType.KneeRight,     new JointStub() }
        };
    }
}
